"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.translatableCollectionResolvers = void 0;
var _handlerGraphql = require("@webiny/handler-graphql");
var _SaveTranslatableCollectionUseCase = require("../useCases/SaveTranslatableCollectionUseCase");
var _GetTranslatableCollectionByIdRepository = require("../repository/GetTranslatableCollectionByIdRepository");
var _GqlTranslatableCollectionMapper = require("./GqlTranslatableCollectionMapper");
const translatableCollectionResolvers = exports.translatableCollectionResolvers = {
  TranslationsQuery: {
    getTranslatableCollection: async (_, args, context) => {
      try {
        const getById = new _GetTranslatableCollectionByIdRepository.GetTranslatableCollectionByIdRepository(context);
        const collection = await getById.execute(args.collectionId);
        return new _handlerGraphql.Response(_GqlTranslatableCollectionMapper.GqlTranslatableCollectionMapper.toDTO(collection));
      } catch (err) {
        return new _handlerGraphql.ErrorResponse(err);
      }
    }
  },
  TranslationsMutation: {
    saveTranslatableCollection: async (_, args, context) => {
      const {
        collectionId,
        items
      } = args;
      try {
        const useCase = new _SaveTranslatableCollectionUseCase.SaveTranslatableCollectionUseCase(context);
        const collection = await useCase.execute({
          collectionId,
          items
        });
        return new _handlerGraphql.Response(_GqlTranslatableCollectionMapper.GqlTranslatableCollectionMapper.toDTO(collection));
      } catch (err) {
        return new _handlerGraphql.ErrorResponse(err);
      }
    }
  }
};

//# sourceMappingURL=resolvers.js.map