"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GetOrCreateTranslatedCollectionUseCase = void 0;
var _TranslatedCollection = require("../domain/TranslatedCollection");
var _GetTranslatedCollectionUseCase = require("./GetTranslatedCollectionUseCase");
var _GetOrCreateTranslatableCollectionUseCase = require("../../translatableCollection/useCases/GetOrCreateTranslatableCollectionUseCase");
var _TranslatedItem = require("../domain/TranslatedItem");
class GetOrCreateTranslatedCollectionUseCase {
  constructor(context) {
    this.context = context;
  }
  async execute(params) {
    // Get base collection.
    const getBaseCollection = new _GetOrCreateTranslatableCollectionUseCase.GetOrCreateTranslatableCollectionUseCase(this.context);
    const baseCollection = await getBaseCollection.execute(params.collectionId);
    let translatedCollection;
    try {
      const getTranslatedCollection = new _GetTranslatedCollectionUseCase.GetTranslatedCollectionUseCase(this.context);
      translatedCollection = await getTranslatedCollection.execute(params);
    } catch (err) {
      if (err.code !== "NOT_FOUND") {
        throw err;
      }
      translatedCollection = new _TranslatedCollection.TranslatedCollection({
        collectionId: params.collectionId,
        languageCode: params.languageCode,
        items: []
      });
    }

    // Make sure the `TranslatedCollection` is in sync with its base `TranslatableCollection`.
    const translatedItems = translatedCollection.getItems();
    const syncItems = baseCollection.getItems().map(bi => {
      const matchingItem = translatedItems.find(ti => ti.itemId === bi.itemId);
      if (matchingItem) {
        return matchingItem;
      }
      return _TranslatedItem.TranslatedItem.create({
        itemId: bi.itemId
      });
    });
    translatedCollection.setItems(syncItems);
    return translatedCollection;
  }
}
exports.GetOrCreateTranslatedCollectionUseCase = GetOrCreateTranslatedCollectionUseCase;

//# sourceMappingURL=GetOrCreateTranslatedCollectionUseCase.js.map